# Changelog

## 0.2.0 (2026-03-18)

Full Changelog: [v0.1.0...v0.2.0](https://github.com/AlphaxivCat/alphaxiv_cat-python/compare/v0.1.0...v0.2.0)

### Features

* **api:** api update ([438a91a](https://github.com/AlphaxivCat/alphaxiv_cat-python/commit/438a91a5e8f50bd4a38b6feb259dad63d5d440f6))


### Bug Fixes

* **deps:** bump minimum typing-extensions version ([9527c40](https://github.com/AlphaxivCat/alphaxiv_cat-python/commit/9527c4029bb2fadf5317f1a72fc3c79f39367f8a))
* **pydantic:** do not pass `by_alias` unless set ([52dbac9](https://github.com/AlphaxivCat/alphaxiv_cat-python/commit/52dbac91a77497a3f205fca239b8ed9c43954f08))


### Chores

* **internal:** tweak CI branches ([a044472](https://github.com/AlphaxivCat/alphaxiv_cat-python/commit/a0444720e67449ae6ed83d4d96f1cd6f32ed64ae))

## 0.1.0 (2026-03-12)

Full Changelog: [v0.0.1...v0.1.0](https://github.com/AlphaxivCat/alphaxiv_cat-python/compare/v0.0.1...v0.1.0)

### Features

* **api:** manual updates ([780ee59](https://github.com/AlphaxivCat/alphaxiv_cat-python/commit/780ee59bb3c4d2e926b9d90beb0d926aeff183b7))


### Chores

* update SDK settings ([cc961f6](https://github.com/AlphaxivCat/alphaxiv_cat-python/commit/cc961f6b7ce42476ef2eac1db99e21a76f30c2da))
* update SDK settings ([74004da](https://github.com/AlphaxivCat/alphaxiv_cat-python/commit/74004da415d4d8b1f68d9bc160d5d16a47053cf5))
* update SDK settings ([d695929](https://github.com/AlphaxivCat/alphaxiv_cat-python/commit/d69592934352b7b25fcf7fe8fd4de41690b85e53))
